
* Webpage: https://gammapy.org
* Documentation: https://docs.gammapy.org
* Code: https://github.com/gammapy/gammapy

Gammapy is an open-source Python package for gamma-ray astronomy built on Numpy, Scipy and Astropy.
It is the base library for the science analysis tools of the Cherenkov Telescope Array Observatory
and can also be used to analyse data from existing gamma-ray telescopes.
